@@ -3,7 +3,7 @@ fixDateTimeOriginal <- function(inDir,
 
   if(Sys.which("exiftool") == "") stop("cannot find ExifTool", call. = FALSE)
   stopifnot(is.logical(recursive))
-  if(!file.exists(inDir)) stop(paste("Could not find inDir: ", inDir), call. = FALSE)
+  if(!dir.exists(inDir)) stop("Could not find inDir:\n", inDir, call. = FALSE)
 
   command.tmp  <- paste('exiftool "-DateTimeOriginal>DateTimeOriginal" ',  ifelse(recursive, '-r ', '') , '-overwrite_original -ext JPG "', inDir, '"', sep = '')
 
